import pytest
from quixote import cleanup

from wcs.workflows import Workflow

from ..admin_pages.test_all import create_superuser
from ..utilities import clean_temporary_pub, create_temporary_pub, get_app, login


def setup_module(module):
    cleanup()


def teardown_module(module):
    clean_temporary_pub()


@pytest.fixture
def pub():
    pub = create_temporary_pub()
    pub.cfg['language'] = {'language': 'en'}
    pub.cfg['identification'] = {'methods': ['password']}
    pub.write_cfg()
    return pub


def test_display_message_migrate(pub):
    workflow = Workflow(name='display message to')
    st1 = workflow.add_status('Status1', 'st1')
    display_message = st1.add_action('displaymsg')
    display_message.level = None
    display_message.message = '<div class="errornotice">message</div>'
    workflow.store()

    workflow.migrate()
    assert workflow.possible_status[0].items[0].level == 'error'
    assert workflow.possible_status[0].items[0].message == 'message'

    # check the migration is skipped if there's an extra class
    display_message.level = None
    display_message.message = '<div class="errornotice blah">message</div>'
    workflow.store()
    workflow.migrate()
    assert not workflow.possible_status[0].items[0].level
    assert workflow.possible_status[0].items[0].message == '<div class="errornotice blah">message</div>'


def test_display_message_rich_text(pub):
    create_superuser(pub)

    workflow = Workflow(name='display message to')
    st1 = workflow.add_status('Status1', 'st1')
    display_message = st1.add_action('displaymsg')
    display_message.message = '<p>hello world</p>'
    workflow.store()

    app = login(get_app(pub))
    resp = app.get(display_message.get_admin_url())
    assert resp.pyquery('textarea[data-godo-schema]')  # godo

    display_message.message = '<table><tr><td>hello world</td></tr></table>'
    workflow.store()
    resp = app.get(display_message.get_admin_url())
    assert resp.pyquery('textarea[data-config]')  # ckeditor
